@@ -1,5 +1,6 @@
 import pdb
 
+from stoobly_agent.app.api.simple_http_request_handler import SimpleHTTPRequestHandler
 from stoobly_agent.app.models.query_param_model import QueryParamModel
 from stoobly_agent.app.settings import Settings
 
@@ -21,14 +22,19 @@ class QueryParamsController:
 
     # GET /requests/:requestId/query_params
     def index(self, context):
-
         context.parse_path_params({
             'requestId': 1
         })
-        
-        requests = QueryParamModel(Settings.instance()).index(context.params.get('requestId'), **context.params)
+
+        query_param_model = self.__query_param_model(context)
+        requests = query_param_model.index(context.params.get('requestId'), **context.params)
 
         context.render(
             json = requests,
             status = 200
-        )
\ No newline at end of file
+        )
+
+    def __query_param_model(self, context: SimpleHTTPRequestHandler):
+        query_param_model = QueryParamModel(Settings.instance())
+        query_param_model.as_remote() if context.headers.get('access-token') else query_param_model.as_local()
+        return query_param_model
\ No newline at end of file
