@@ -1,3 +1,4 @@
+import json
 import pdb
 import requests
 
@@ -8,15 +9,15 @@ from urllib.parse import urlparse
 from stoobly_agent.app.api.simple_http_request_handler import SimpleHTTPRequestHandler
 from stoobly_agent.app.cli.helpers.context import ReplayContext
 from stoobly_agent.app.models.adapters.joined_request_adapter import JoinedRequestAdapter
-from stoobly_agent.app.models.adapters.mitmproxy_request_adapter import MitmproxyRequestAdapter
-from stoobly_agent.app.models.adapters.mitmproxy_response_adapter import MitmproxyResponseAdapter
+from stoobly_agent.app.models.adapters.python import PythonRequestAdapterFactory, PythonResponseAdapterFactory
 from stoobly_agent.app.models.adapters.raw_http_request_adapter import RawHttpRequestAdapter
 from stoobly_agent.app.models.adapters.raw_http_response_adapter import RawHttpResponseAdapter
 from stoobly_agent.app.models.request_model import RequestModel
 from stoobly_agent.app.models.schemas.request import Request
-from stoobly_agent.app.proxy.replay.replay_request_service import replay_with_rewrite
+from stoobly_agent.app.proxy.replay.replay_request_service import replay
 from stoobly_agent.app.proxy.upload.upload_request_service import upload_staged_request
 from stoobly_agent.app.settings import Settings
+from stoobly_agent.config.constants import mode
 from stoobly_agent.lib.orm.replayed_response import ReplayedResponse
 from stoobly_agent.lib.orm.request import Request as OrmRequest
 
@@ -53,8 +54,8 @@ class RequestsController:
         request_adapter = RawHttpRequestAdapter(joined_request.request_string.get())
         response_adapter = RawHttpResponseAdapter(joined_request.response_string.get())
 
-        mitmproxy_request = MitmproxyRequestAdapter(request_adapter.protocol, request_adapter.to_request()).adapt()
-        mitmproxy_response = MitmproxyResponseAdapter(response_adapter.protocol, response_adapter.to_response()).adapt()
+        mitmproxy_request = PythonRequestAdapterFactory(request_adapter.to_request()).mitmproxy_request(request_adapter.protocol)
+        mitmproxy_response = PythonResponseAdapterFactory(response_adapter.to_response()).mitmproxy_response(response_adapter.protocol)
 
         class MitmproxyFlowMock():
             def __init__(self, request, response):
@@ -206,10 +207,17 @@ class RequestsController:
 
     # PUT /requests/send
     def send(self, context: SimpleHTTPRequestHandler):
+        headers = []
+
+        try:
+            headers = json.load(context.params.get('headers'))
+        except Exception as e:
+            pass
+
         url = urlparse(context.params.get('url'))
         request_response = {
             'body': context.params.get('body'),
-            'headers': context.params.get('headers'),
+            'headers': headers,
             'method': context.params.get('method'),
             'path': url.path,
             'password': url.password,
@@ -235,14 +243,14 @@ class RequestsController:
 
     def __send(self, context: SimpleHTTPRequestHandler, replay_context: ReplayContext, callback = None):
         now = time()
-        res = replay_with_rewrite(replay_context)
+        res = replay(replay_context, { 'mode': mode.REPLAY })
         received_at = time()
 
         if callback:
             callback(context, res, int((received_at - now) * 1000))
 
         context.render(
-            data = res.raw.data,
+            data = res.raw.data if hasattr(res, 'raw') else res.content,
             headers = res.headers,
             status = res.status_code
         )
