@@ -2,12 +2,12 @@ import requests
 import time
 import pdb
 
-from mitmproxy.http import HTTPFlow as MitmproxyHTTPFlow
 from mitmproxy.http import Request as MitmproxyRequest
 from typing import Callable, TypedDict
 
 from stoobly_agent.app.models.request_model import RequestModel
-from stoobly_agent.app.proxy.intercept_settings import InterceptSettings
+from stoobly_agent.app.proxy.mitmproxy.request_facade import MitmproxyRequestFacade
+from stoobly_agent.app.proxy.utils.rewrite_rules_to_ignored_components_service import rewrite_rules_to_ignored_components
 from stoobly_agent.config.constants import custom_headers, mock_policy
 from stoobly_agent.lib.logger import Logger
 
@@ -31,14 +31,27 @@ class MockOptions(TypedDict):
 # @param request [mitmproxy.http.Request]
 # @param settings [Dict]
 #
-def handle_request_mock_generic(context: MockContext, intercept_settings: InterceptSettings, **options: MockOptions):
+def handle_request_mock_generic(context: MockContext, **options: MockOptions):
+    intercept_settings = context.intercept_settings
     request_model = RequestModel(intercept_settings.settings)
     request: MitmproxyRequest = context.flow.request
 
-    eval_request = inject_eval_request(request_model, intercept_settings)
+    # Rewrite request with paramter rules for mock
+    request_facade = MitmproxyRequestFacade(request)
+    rewrite_rules = intercept_settings.rewrite_rules
+    request_facade.with_rewrite_rules(rewrite_rules).rewrite()
+
+    # If ignore rules are set, then ignore specified request parameters
+    ignore_rules = intercept_settings.ignore_rules
+    if len(ignore_rules) > 0:
+        _ignore_rules = request_facade.select_parameter_rules(ignore_rules)
+        ignored_components = rewrite_rules_to_ignored_components(_ignore_rules)
+        options['ignored_components'] += ignored_components  if 'ignored_components' in options else ignored_components
+
     handle_success = options['success'] if 'success' in options and callable(options['success']) else None
     handle_failure = options['failure'] if 'failure' in options and callable(options['failure']) else None
     
+    eval_request = inject_eval_request(request_model, intercept_settings)
     policy = get_active_mode_policy(request, intercept_settings)
  
     if policy == mock_policy.NONE:
@@ -83,13 +96,10 @@ def eval_request_with_retry(eval_request, request, **options: MockOptions):
 
     return res
 
-def handle_request_mock(flow: MitmproxyHTTPFlow, intercept_settings: InterceptSettings):
-    context = MockContext(flow)
-
+def handle_request_mock(context: MockContext):
     handle_request_mock_generic(
         context,
-        intercept_settings,
-        failure=lambda context: __handle_mock_failure(context, intercept_settings),
+        failure=lambda context: __handle_mock_failure(context),
         success=lambda context: __handle_mock_success(context)
     )
 
@@ -98,8 +108,9 @@ def __handle_mock_success(context: MockContext) -> None:
     start_time = context.start_time
     __simulate_latency(response.headers.get(custom_headers.RESPONSE_LATENCY), start_time)
 
-def __handle_mock_failure(context: MockContext, intercept_settings: InterceptSettings):
+def __handle_mock_failure(context: MockContext):
     req = context.flow.request
+    intercept_settings = context.intercept_settings
     upstream_url = intercept_settings.upstream_url
 
     Logger.instance().debug(f"{LOG_ID}:ReverseProxy:UpstreamUrl: {upstream_url}")
