@@ -13,7 +13,7 @@ from stoobly_agent.lib.logger import Logger
 
 from .handle_mock_service import handle_request_mock_generic
 from .mock.context import MockContext
-from .test.context import TestContext
+from .test.context_abc import TestContextABC as TestContext
 from .test.test_service import test
 from .upload.upload_test_service import inject_upload_test
 
@@ -43,7 +43,7 @@ def __handle_mock_success(test_context: TestContext) -> None:
     intercept_settings = test_context.intercept_settings
 
     settings = Settings.instance()
-    test_context.with_response_param_names(EndpointsResource(settings.remote.api_url, settings.remote.api_key))
+    test_context.with_endpoints_resource(EndpointsResource(settings.remote.api_url, settings.remote.api_key))
     
     # Run test
     passed, log = test(test_context)
