@@ -6,7 +6,7 @@ from orator.orm import belongs_to
 from stoobly_agent.app.models.schemas.request import Request
 from stoobly_agent.app.proxy.mitmproxy.response_facade import MitmproxyResponseFacade
 from stoobly_agent.app.proxy.upload.response_string import ResponseString
-from stoobly_agent.app.models.adapters.mitmproxy_response_adapter import MitmproxyResponseAdapter
+from stoobly_agent.app.models.adapters.python import PythonResponseAdapterFactory
 
 from .base import Base
 
@@ -14,8 +14,11 @@ class ReplayedResponse(Base):
   __fillable__ = ['latency', 'timestamp', 'raw', 'status', 'request_id']
 
   def with_python_response(self, response: requests.Response):
-    http_version = f"HTTP/{response.raw.version / 10.0}"
-    mitmproxy_response = MitmproxyResponseAdapter(http_version, response).adapt()
+    http_version = 'HTTP/1.1'
+    if hasattr(response, 'raw'):
+      http_version = f"HTTP/{response.raw.version / 10.0}"
+
+    mitmproxy_response = PythonResponseAdapterFactory(http_version).mitmproxy_response(response).adapt()
     adapted_response = MitmproxyResponseFacade(mitmproxy_response)
     response_string = ResponseString(adapted_response, None) 
     self.raw = response_string.get()
